# Changelog - Spin-Tether Paper

All notable changes to this project will be documented in this file.

## [v23-published] - 2025-06-01 - "Publication Release"

### Added
- Published on viXra.org at https://ai.vixra.org/
- New README.md with compelling Reddit-style introduction
- Expanded philosophical sections on spacetime emergence from spin
- Enhanced acknowledgments recognizing AI collaboration

### Changed
- Final refinements to abstract emphasizing philosophical insight
- Updated introduction to better integrate the guiding principle
- Improved consistency of "atoms are balls" messaging throughout
- Clarified that gravity is the centripetal force of spacetime

### Fixed
- Minor LaTeX formatting issues
- Reference formatting consistency
- Ensured zero free parameters claim is prominent
- Final proofreading corrections

## [v23] - 2025-06-01 - "Atoms are Balls"

### Changed
- **Complete paradigm shift**: Renamed to "Atoms are Balls: Why Three-Dimensional Rotation Explains Atomic Binding from Hydrogen to Gold"
- **Multi-atom verification**: Extended analysis from just hydrogen to H, He, C, Fe, Au
- **Core message clarity**: Emphasized 2D vs 3D atomic conceptualization as the key insight

### Added
- `verify_atoms_balls.py` - Proves concept works across periodic table
- Table showing 99%+ agreement for 5 different atoms
- Clearer connection to quantum gravity implications
- Executive summary document

### Fixed
- Repositioned work as discovery rather than theory
- Made "zero free parameters" achievement prominent
- Clarified that electromagnetic force = quantum gravity at atomic scale

## [v22] - 2025-05-27 - "Computational Honesty"

### Added
- Systematic analysis of 8 open stellar clusters
- Galaxy rotation curve analysis showing framework failures
- Scale-dependent σ(r,M,ρ) function with three factors
- Unified Force-Energy world formula: E² = (pc)² + (mc²)² + E_spin + E_tether + E_bind
- Critical assessment section acknowledging limitations
- Computational validation plots and quantitative tables

### Changed
- Modified σ from constant to σ(r,M,ρ) with mass and density dependence
- Updated abstract to be honest about failures from the start
- Reframed as "exploring connections" not "unified theory"

### Fixed
- Acknowledged galaxy rotation curves fail (σ exceeds limits by 36-200×)
- Stated clearly: "cannot replace dark matter"
- Made limitations explicit throughout

## [v21] - 2025-05-20 - "Modular Structure"

### Changed
- Split monolithic document into modular .tex files
- Organized into: header, theory, examples, observations
- Created main_document.tex that includes all sections

### Added
- README explaining file structure
- Bibliography as separate .bib file
- Compilation instructions

## [v10-v20] - 2025-04-01 to 2025-05-15 - "Development Phase"

### Evolution
- v10: First attempt at unified framework
- v12: Added solar system examples
- v15: Included S2 star analysis  
- v18: Added cluster analysis
- v20: Recognized galaxy rotation failures

## [v01-v09] - 2025-01-15 to 2025-03-30 - "Initial Explorations"

### The Journey
- v01: Dog walk inspiration - "what if forces are like leashes?"
- v03: First mathematical formulation F = ℏ²s²/(γmr³)
- v05: Realized it reproduces hydrogen Coulomb force exactly
- v07: Extended to planetary orbits successfully
- v09: Started questioning 2D vs 3D atomic models

## [v00] - 2025-01-14 - "The Walk"

### Created
- Initial insight during morning dog walk
- Noticed similarity between dog on leash and electron around nucleus
- First sketch of unified binding force concept

---

## Key Milestones

- **2025-01-14**: Initial inspiration (dog walk)
- **2025-02-01**: Mathematical formalization with AI help
- **2025-03-15**: Discovered hydrogen Coulomb force match
- **2025-04-20**: Successfully predicted Mercury's perihelion
- **2025-05-10**: Failed at galaxy scales (important negative result)
- **2025-05-27**: v22 - Computational honesty version
- **2025-06-01**: v23 - "Atoms are Balls" paradigm shift
- **2025-06-01**: v23-published - Released on viXra.org

## Collaborators

- **Andre Heinecke**: Original concept and primary author
- **Caseway's Fast and Furious Bilbo**: Canine inspiration
- **ChatGPT-4**: Early mathematical development
- **Claude Opus 4**: Later refinements and v23 restructuring

## Philosophy

This changelog preserves not just what changed, but HOW we arrived at these insights. The path from a dog walk to quantum gravity is as important as the destination.
